class puppet_server::puppetdb(
  $server_urls = [ 'http://localhost:8080' ],
  $soft_write_failure = false,
  $masterless = false,
) inherits puppet_server::params {

  $confdir = '/etc/puppet'
  Ini_setting {
    ensure  => present,
    path    => "${confdir}/puppetdb.conf",
    section => 'main'
  }

  # Start
  # puppetdb.conf
  file { "${confdir}/puppetdb.conf":
    mode    => '0644',
  }

  validate_array($server_urls)
  ini_setting { 'puppetdb.conf_server_urls':
    setting => 'server_urls',
    value   => join($server_urls, ','),
  }

  ini_setting { 'puppetdb.conf_soft_write_failure':
    setting => 'soft_write_failure',
    value   => $soft_write_failure,
  }
  # End

  /*
  puppet config set storeconfigs true --section master
  puppet config set storeconfigs_backend puppetdb --section master
  puppet config set reports puppetdb --section master
  puppet config set trusted_node_data true --section master
  */

  file { "${confdir}/routes.yaml":
    ensure  => present,
    content => template('puppet_server/routes.yaml.erb'),
    owner   => 'puppet',
    group   => 'puppet',
    mode    => '0444',
  }
}
